from django.urls import include, path, reverse_lazy

from django.contrib.auth import views as auth_views

from . import views
from .forms import login_form_helper, password_reset_form_helper

app_name = 'users'

urlpatterns = [
    path('', views.user_list, name="user_list"),
    path('add/', views.user_add, name="user_add"),
    path('<int:pk>/edit/', views.user_edit, name="user_edit"),
    path('profile/', views.user_profile, name="user_profile"),
    path(
        'login/',
        auth_views.LoginView.as_view(extra_context={"helper": login_form_helper}, success_url=reverse_lazy('dash')),
        name="login",
    ),
    path('logout/', auth_views.LogoutView.as_view(), name="logout"),
    path(
        'password-reset/',
        auth_views.PasswordResetView.as_view(
            template_name="registration/password_reset.html",
            extra_context={"helper": password_reset_form_helper},
        ),
        name="password_reset",
    ),
]
